<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ConnectionInfo</name>
    <message>
        <location filename="../src/connectioninfo.ui" line="14"/>
        <source>Connection information</source>
        <translation>Verbindingsinformatie</translation>
    </message>
</context>
<context>
    <name>NmList</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Dialoogvenster</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="17"/>
        <source>All information</source>
        <translation>Alle informatie</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="27"/>
        <source>Active connections</source>
        <translation>Actieve verbindingen</translation>
    </message>
    <message>
        <location filename="../src/nmlist.ui" line="37"/>
        <source>Available wireless</source>
        <translation>Beschikbare draadloze verbindingen</translation>
    </message>
</context>
<context>
    <name>NmModel</name>
    <message>
        <location filename="../src/nmmodel.cpp" line="56"/>
        <source>nm-tray - wireless password</source>
        <translation>nm-tray - draadloos wachtwoord</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="57"/>
        <source>Password is needed for connection to &apos;%1&apos;:</source>
        <translation>Wachtwoord vereist om te verbinden met &apos;%1&apos;:</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="745"/>
        <source>root</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="747"/>
        <source>active connection(s)</source>
        <translation>actieve verbinding(en)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="749"/>
        <source>connection(s)</source>
        <translation>verbinding(en)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="751"/>
        <source>device(s)</source>
        <translation>appara(a)t(en)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="753"/>
        <source>wifi network(s)</source>
        <translation>wi-fi-netwerk(en)</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1044"/>
        <source>unknown</source>
        <comment>hardware address</comment>
        <translation>onbekend</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1152"/>
        <source>General</source>
        <comment>Active connection information</comment>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1153"/>
        <source>Interface</source>
        <comment>Active connection information</comment>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1155"/>
        <source>Hardware Address</source>
        <comment>Active connection information</comment>
        <translation>Hardware-adres</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1157"/>
        <source>Driver</source>
        <comment>Active connection information</comment>
        <translation>Stuurprogramma</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1159"/>
        <source>Speed</source>
        <comment>Active connection information</comment>
        <translation>Snelheid</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1163"/>
        <source>Kb/s</source>
        <translation>Kb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1165"/>
        <source>Mb/s</source>
        <translation>Mb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1167"/>
        <source>Gb/s</source>
        <translation>Gb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1169"/>
        <source>Tb/s</source>
        <translation>Tb/s</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1172"/>
        <source>unknown</source>
        <comment>Speed</comment>
        <translation>onbekend</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1176"/>
        <source>Security</source>
        <comment>Active connection information</comment>
        <translation>Beveiliging</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1180"/>
        <source>IPv4</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1181"/>
        <source>IPv6</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1192"/>
        <source>IP Address</source>
        <comment>Active connection information</comment>
        <translation>IP-adres</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1194"/>
        <source>Subnet Mask</source>
        <comment>Active connection information</comment>
        <translation>Subnet-mask</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1203"/>
        <source>Default route</source>
        <comment>Active connection information</comment>
        <translation>Standaard route</translation>
    </message>
    <message>
        <location filename="../src/nmmodel.cpp" line="1209"/>
        <source>DNS(%1)</source>
        <comment>Active connection information</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tray</name>
    <message>
        <location filename="../src/tray.cpp" line="123"/>
        <source>&lt;pre&gt;Connection &lt;strong&gt;%1&lt;/strong&gt;(%2) active&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Verbinding &lt;strong&gt;%1&lt;/strong&gt;(%2) actief&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="129"/>
        <source>&lt;pre&gt;No active connection&lt;/pre&gt;</source>
        <translation>&lt;pre&gt;Geen actieve verbinding&lt;/pre&gt;</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="202"/>
        <source>Connection lost</source>
        <translation>Verbinding verbroken</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="203"/>
        <source>No longer connected to %1 &apos;%2&apos;.</source>
        <translation>Niet meer verbonden met %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="215"/>
        <source>Connection established</source>
        <translation>Verbinding gemaakt</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="216"/>
        <source>Now connected to %1 &apos;%2&apos;.</source>
        <translation>Nu verbonden met %1 &apos;%2&apos;.</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="220"/>
        <source>NetworkManager(nm-tray)</source>
        <translation>NetworkManager (nm-tray)</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="253"/>
        <source>Enable Networking</source>
        <translation>Netwerk inschakelen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="254"/>
        <source>Enable Wi-Fi</source>
        <translation>Wi-Fi inschakelen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="256"/>
        <source>Enable notifications</source>
        <translation>Meldingen inschakelen</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="258"/>
        <source>Connection information</source>
        <translation>Verbindingsinformatie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="259"/>
        <source>Debug information</source>
        <translation>Foutopsporingsinformatie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="260"/>
        <source>Wifi - request scan</source>
        <translation>Zoeken naar Wi-Fi-netwerken</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="261"/>
        <source>Edit connections...</source>
        <translation>Verbindingen bewerken...</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="264"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="266"/>
        <source>Quit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="291"/>
        <source>nm-tray info</source>
        <translation>nm-tray-informatie</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="384"/>
        <source>%1 about</source>
        <translation>Over %1</translation>
    </message>
    <message>
        <location filename="../src/tray.cpp" line="385"/>
        <source>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is a simple Qt based frontend for &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Version: %1</source>
        <translation>&lt;strong&gt;&lt;a href=&quot;https://github.com/palinek/nm-tray&quot;&gt;nm-tray&lt;/a&gt;&lt;/strong&gt; is een eenvoudig op Qt gebaseerd front-end voor &lt;a href=&quot;https://wiki.gnome.org/Projects/NetworkManager&quot;&gt;NetworkManager&lt;/a&gt;.&lt;br/&gt;&lt;br/&gt;Versie: %1</translation>
    </message>
</context>
<context>
    <name>WindowMenu</name>
    <message>
        <location filename="../src/windowmenu.cpp" line="163"/>
        <source>Active connection(s)</source>
        <translation>Actieve verbinding(en)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="165"/>
        <source>Wi-Fi network(s)</source>
        <translation>Wi-Fi-netwerk(en)</translation>
    </message>
    <message>
        <location filename="../src/windowmenu.cpp" line="167"/>
        <source>Known connection(s)</source>
        <translation>Opgeslagen verbinding(en)</translation>
    </message>
</context>
</TS>
